@@ -59,7 +59,7 @@ GLOBAL postmkvirtualenv"
 
 test_no_virtualenv () {
     old_path="$PATH"
-    PATH="/usr/bin:/bin:/usr/sbin:/sbin"
+    PATH="/bin:/usr/sbin:/sbin"
     assertFalse "Found virtualenv in $(which virtualenv)" "which virtualenv"
     mkvirtualenv should_not_be_created 2>/dev/null
     RC=$?
